.. _commands-name:

!!!!!!!!
commands
!!!!!!!!

.. meta::
   :keywords: commands, commands

.. index:: commands, commands

.. _commands-title:

Commands
########
If the text ``\{xrst_`` appears in the input, the backslash is removed
form the xrst output and the text does not start an xrst command.
Otherwise the text ``{xrst_`` is reserved for the beginning of an xrst command.
These commands are described in the pages below:

-  :ref:`begin_cmd-title`
-  :ref:`toc_cmd-title`
-  :ref:`spell_cmd-title`
-  :ref:`suspend_cmd-title`
-  :ref:`code_cmd-title`
-  :ref:`literal_cmd-title`
-  :ref:`dir_cmd-title`
-  :ref:`comment_cmd-title`
-  :ref:`comment_ch_cmd-title`

.. toctree::
   :maxdepth: 1
   :hidden:

   begin_cmd
   toc_cmd
   spell_cmd
   suspend_cmd
   code_cmd
   literal_cmd
   dir_cmd
   comment_cmd
   comment_ch_cmd
